<?php

namespace Drupal\mymodule\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CssCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

class AjaxForm extends FormBase {
  public function getFormId() {
    return 'mymodule_ajax_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['name'] = array(
      '#type' => 'textfield',
      '#title' => 'Name',
      '#required' => TRUE,
      '#prefix' => '',
      '#suffix' => '<div class="name-validation-message"></div>',
    );

    $form['email'] = array(
      '#type' => 'email',
      '#title' => 'Email',
      '#required' => TRUE,
      '#prefix' => '',
      '#suffix' => '<div class="email-validation-message"></div>',
      '#ajax' => [
      'callback' => [$this, 'validateEmailCallbackAjax'],
      'event' => 'change',
      'wrapper' => 'edit-email',
    ],
    );

    $form['url'] = array(
      '#type' => 'textfield',
      '#title' => 'URL',
      '#required' => TRUE,
      '#prefix' => '',
      '#suffix' => '<div class="url-validation-message"></div>',
      '#ajax' => [
        'callback' => [$this, 'validateUrlCallbackAjax'],
        'event' => 'change',
        'wrapper' => 'edit-email',
      ],
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => 'Click',
    );
    return $form;
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {


    $url = $form_state->getValue('url');

    $regexp = '/^(https|http):\/\//';
    $checkHttp = (bool)preg_match($regexp, $url);
    if ($checkHttp) {
      $url[4] == 's' ? $httpOrHttps = 8 : $httpOrHttps = 7;
      $checkHttp ? $url = substr($url, $httpOrHttps) : '';
    }

    $regexp = '/^www./';
    $checkWww = ((bool)preg_match($regexp, $url));
    if ($checkWww) {
      $url = substr($url, 4);
    }

    $regexp = '/^([a-z0-9]*.[rр][uф])/';
    $checkUrl = (bool)preg_match($regexp, $url);

    $url = explode('.',$url);
    $url = $url[0] . '.' . $url[1];

  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $query = \Drupal::database()->insert('AAA_custom_table');
    $query->fields([
      'name' => $form_state->getValue('name'),
      'email' => $form_state->getValue('email'),
      'url' => $form_state->getValue('url'),
    ]);
    $query->execute();
  }

  public function validateEmailCallbackAjax(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $email = $form_state->getValue('email');
    $email_valid = filter_var($email, FILTER_VALIDATE_EMAIL);
    if (!$email_valid and !empty($email)) {
      $response->addCommand(new HtmlCommand('.email-validation-message', 'Введен не корректный email'));
      $response->addCommand(new CssCommand('.email-validation-message', ['color' => 'red']));
      $response->addCommand(new CssCommand('#edit-email', ['border' => '1px solid red']));
    } else {
      $response->addCommand(new HtmlCommand('.email-validation-message', ''));
      $response->addCommand(new CssCommand('#edit-email', ['border' => '']));
    }
    return $response;
  }

  public function validateUrlCallbackAjax(array &$form, FormStateInterface $formState) {
    $response = new AjaxResponse();
    $response->addCommand(new HtmlCommand('.url-validation-message', 'ZXC'));
    $response->addCommand(new CssCommand('#edit-url', ['border' => '1px solid red']));
    return $response;
  }
}
